/*
 * "Darkfish" Rdoc CSS
 * $Id$
 * 
 * Author: Michael Granger <ged@FaerieMUD.org>
 * 
 */

/* Base Green is: #660000 */

*{ padding: 0; margin: 0; }

body {
    background: #efefef;
	font: 14px "Helvetica Neue", Helvetica, Tahoma, sans-serif;
}
body.class, body.module, body.file {
    margin-left: 40px;
}
body.file-popup {
	font-size: 90%;
	margin-left: 0;
}

h1 {
	font-size: 300%;
	text-shadow: rgba(135,145,135,0.65) 2px 2px 3px;
	color: #660000;
}
h2,h3,h4 { margin-top: 1.5em; }

a {
	color: #660000;
	text-decoration: none;
}
a:hover {
 	border-bottom: 1px dotted #660000;
}

pre {
	background: #ddd;
	padding: 0.5em 0;
}


/* @group Generic Classes */

.initially-hidden {
	display: none;
}

.quicksearch-field {
	width: 98%;
	background: #ddd;
	border: 1px solid #aaa;
	height: 1.5em;
	-webkit-border-radius: 4px;
}
.quicksearch-field:focus {
	background: #f1edba;
}

.missing-docs {
	font-size: 120%;
	background: white url(images/wrench_orange.png) no-repeat 4px center;
	color: #FFC200;
	line-height: 2em;
	border: 1px solid #d00;
	opacity: 1;
	padding-left: 20px;
	text-indent: 24px;
	letter-spacing: 3px;
	font-weight: bold;
	-webkit-border-radius: 5px;
	-moz-border-radius: 5px;
}

.target-section {
	border: 2px solid #dcce90;
	border-left-width: 8px;
	padding: 0 1em;
	background: #fff3c2;
}

/* @end */


/* @group Index Page, Standalone file pages */
body.indexpage {
	margin: 1em 3em;
}
body.indexpage p,
body.indexpage div,
body.file p {
	margin: 1em 0;
}

.indexpage ul,
.file #documentation ul {
	line-height: 160%;
	list-style: none;
}
.indexpage ul a,
.file #documentation ul a {
	font-size: 16px;
}

.indexpage li,
.file #documentation li {
	padding-left: 20px;
	background: url(images/bullet_black.png) no-repeat left 4px;
}
.indexpage li.module {
	background: url(images/package.png) no-repeat left 4px;
}
.indexpage li.class {
	background: url(images/ruby.png) no-repeat left 4px;
}
.indexpage li.file {
	background: url(images/page_white_text.png) no-repeat left 4px;
}

/* @end */

/* @group Top-Level Structure */

.class #metadata,
.file #metadata,
.module #metadata {
	float: left;
	width: 260px;
}

.class #documentation,
.file #documentation,
.module #documentation {
	margin: 2em 1em 5em 300px;
	min-width: 340px;
}

.file #metadata {
	margin: 0.8em;
}

#validator-badges {
	clear: both;
	margin: 1em 1em 2em;
}

/* @end */

/* @group Metadata Section */
#metadata .section {
	background-color: #F2F5ED;
	-moz-border-radius: 5px;
	-webkit-border-radius: 5px;
	border: 1px solid #aaa;
	margin: 0 8px 16px;
	font-size: 90%;
	overflow: hidden;
}
#metadata h3.section-header {
	margin: 0;
	padding: 2px 8px;
	background: #FFC200;
	color: #505050;
	-moz-border-radius-topleft: 4px;
	-moz-border-radius-topright: 4px;
	-webkit-border-top-left-radius: 4px;
	-webkit-border-top-right-radius: 4px;
	border-bottom: 1px solid #aaa;
}
#metadata ul,
#metadata dl,
#metadata p {
	padding:  8px;
	list-style: none;
}

#file-metadata ul {
	padding-left: 28px;
	list-style-image: url(images/page_green.png);
}

dl.svninfo {
	color: #505050;
	margin: 0;
}
dl.svninfo dt {
	font-weight: bold;
}

ul.link-list li {
	white-space: nowrap;
}
ul.link-list .type {
	font-size: 8px;
	text-transform: uppercase;
	color: white;
	background: #969696;
	padding: 2px 4px;
	-webkit-border-radius: 5px;
}

/* @end */


/* @group Project Metadata Section */
#project-metadata {
	margin-top: 3em;
}

.file #project-metadata {
  margin-top: 0em;
}

#project-metadata .section {
	border: 1px solid #aaa;
}
#project-metadata h3.section-header {
	border-bottom: 1px solid #aaa;
	position: relative;
}
#project-metadata h3.section-header .search-toggle {
	position: absolute;
	right: 5px;
}


#project-metadata form {
	color: #777;
	background: #FFC200;
	padding: 8px 8px 16px;
	border-bottom: 1px solid #bbb;
}
#project-metadata fieldset {
	border: 0;
}

#no-class-search-results {
	margin: 0 auto 1em;
	text-align: center;
	font-size: 14px;
	font-weight: bold;
	color: #aaa;
}

/* @end */


/* @group Documentation Section */
#description {
	font-size: 100%;
	color: #333;
}

#description p {
	margin: 1em 0.4em;
}

#description ul {
	margin-left: 2em;
}
#description ul li {
	line-height: 1.4em;
}

#description dl,
#documentation dl {
	margin: 8px 1.5em;
	border: 1px solid #FFC200;
}
#description dl {
	font-size: 14px;
}

#description dt,
#documentation dt {
	padding: 2px 4px;
	font-weight: bold;
	background: #ddd;
}
#description dd,
#documentation dd  {
	padding: 2px 12px;
}
#description dd + dt,
#documentation dd + dt {
	margin-top: 0.7em;
}

#documentation .section {
	font-size: 90%;
}
#documentation h3.section-header {
	margin-top: 2em;
	padding: 0.75em 0.5em;
	background-color: #F2F5ED;
	color: #333;
	font-size: 150%;
	border: 1px solid #bbb;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
}

#constants-list > dl,
#attributes-list > dl {
	margin: 1em 0 2em;
	border: 0;
}
#constants-list > dl dt,
#attributes-list > dl dt {
	padding-left: 0;
	font-weight: bold;
	font-family: Monaco, "Andale Mono";
	background: inherit;
}
#constants-list > dl dt a,
#attributes-list > dl dt a {
	color: inherit;
}
#constants-list > dl dd,
#attributes-list > dl dd {
	margin: 0 0 1em 0;
	padding: 0;
	color: #505050;
}

/* @group Method Details */

#documentation .method-source-code {
	display: none;
}

#documentation .method-detail {
	margin: 0.5em 0;
	padding: 0.5em 0;
	cursor: pointer;
}
#documentation .method-detail:hover {
	background-color: #f1edba;
}
#documentation .method-alias {
	font-style: oblique;
}
#documentation .method-heading {
	position: relative;
	padding: 2px 4px 0 20px;
	font-size: 125%;
	font-weight: bold;
	color: #333;
	background: url(images/brick.png) no-repeat left bottom;
}
#documentation .method-heading a {
	color: inherit;
}
#documentation .method-click-advice {
	position: absolute;
	top: 2px;
	right: 5px;
	font-size: 10px;
	color: #9b9877;
	visibility: hidden;
	padding-right: 20px;
	line-height: 20px;
	background: url(images/zoom.png) no-repeat right top;
}
#documentation .method-detail:hover .method-click-advice {
	visibility: visible;
}

#documentation .method-alias .method-heading {
	color: #505050;
	background: url(images/brick_link.png) no-repeat left bottom;
}

#documentation .method-description,
#documentation .aliases {
	margin: 0 20px;
	line-height: 1.2em;
	color: #505050;
}
#documentation .aliases {
	padding-top: 4px;
	font-style: italic;
	cursor: default;
}
#documentation .method-description p {
	padding: 0;
}
#documentation .method-description p + p {
	margin-bottom: 0.5em;
}

#documentation .attribute-method-heading {
	background: url(images/tag_green.png) no-repeat left bottom;
}
#documentation #attribute-method-details .method-detail:hover {
	background-color: transparent;
	cursor: default;
}
#documentation .attribute-access-type {
	font-size: 60%;
	text-transform: uppercase;
	vertical-align: super;
	padding: 0 2px;
}
/* @end */

/* @end */



/* @group Source Code */

a.source-toggle {
	font-size: 90%;
}
a.source-toggle img {
	
}

div.method-source-code {
    background: #262626;
    color: #efefef;
    margin: 1em;
    padding: 0.5em;
    border: 1px dashed #999;
    overflow: hidden;
}

div.method-source-code pre {
	background: inherit;
	padding: 0;
	color: white;
	overflow: hidden;
}

/* @group Ruby keyword styles */

.standalone-code { background: #221111; color: #ffdead; overflow: hidden; }

.ruby-constant  { color: #7fffd4; background: transparent; }
.ruby-keyword { color: #00ffff; background: transparent; }
.ruby-ivar    { color: #eedd82; background: transparent; }
.ruby-operator  { color: #00ffee; background: transparent; }
.ruby-identifier { color: #ffdead; background: transparent; }
.ruby-node    { color: #ffa07a; background: transparent; }
.ruby-comment { color: #b22222; font-weight: bold; background: transparent; }
.ruby-regexp  { color: #ffa07a; background: transparent; }
.ruby-value   { color: #7fffd4; background: transparent; }

/* @end */
/* @end */


/* @group File Popup Contents */

.file #metadata,
.file-popup #metadata {
}

.file-popup dl {
	font-size: 80%;
	padding: 0.75em;
	background-color: #F2F5ED;
	color: #333;
	border: 1px solid #bbb;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
}
.file dt {
	font-weight: bold;
	padding-left: 22px;
	line-height: 20px;
	background: url(images/page_white_width.png) no-repeat left top;
}
.file dt.modified-date {
	background: url(images/date.png) no-repeat left top;
}
.file dt.requires {
	background: url(images/plugin.png) no-repeat left top;
}
.file dt.scs-url {
	background: url(images/wrench.png) no-repeat left top;
}

.file dl dd {
	margin: 0 0 1em 0;
}
.file #metadata dl dd ul {
	list-style: circle;
	margin-left: 20px;
	padding-top: 0;
}
.file #metadata dl dd ul li {
}


.file h2 {
	margin-top: 2em;
	padding: 0.75em 0.5em;
	background-color: #F2F5ED;
	color: #333;
	font-size: 120%;
	border: 1px solid #bbb;
	-moz-border-radius: 3px;
	-webkit-border-radius: 3px;
}

/* @end */




/* @group ThickBox Styles */
#TB_window {
	font: 12px Arial, Helvetica, sans-serif;
	color: #333333;
}

#TB_secondLine {
	font: 10px Arial, Helvetica, sans-serif;
	color:#505050666;
}

#TB_window a:link {color: #505050666;}
#TB_window a:visited {color: #505050666;}
#TB_window a:hover {color: #000;}
#TB_window a:active {color: #505050666;}
#TB_window a:focus{color: #505050666;}

#TB_overlay {
	position: fixed;
	z-index:100;
	top: 0px;
	left: 0px;
	height:100%;
	width:100%;
}

.TB_overlayMacFFBGHack {background: url(images/macFFBgHack.png) repeat;}
.TB_overlayBG {
	background-color:#000;
	filter:alpha(opacity=75);
	-moz-opacity: 0.75;
	opacity: 0.75;
}

* html #TB_overlay { /* ie6 hack */
     position: absolute;
     height: expression(document.body.scrollHeight > document.body.offsetHeight ? document.body.scrollHeight : document.body.offsetHeight + 'px');
}

#TB_window {
	position: fixed;
	background: #ffffff;
	z-index: 102;
	color:#000000;
	display:none;
	border: 4px solid #525252;
	text-align:left;
	top:50%;
	left:50%;
}

* html #TB_window { /* ie6 hack */
position: absolute;
margin-top: expression(0 - parseInt(this.offsetHeight / 2) + (TBWindowMargin = document.documentElement && document.documentElement.scrollTop || document.body.scrollTop) + 'px');
}

#TB_window img#TB_Image {
	display:block;
	margin: 15px 0 0 15px;
	border-right: 1px solid #FFC200;
	border-bottom: 1px solid #FFC200;
	border-top: 1px solid #505050;
	border-left: 1px solid #505050;
}

#TB_caption{
	height:25px;
	padding:7px 30px 10px 25px;
	float:left;
}

#TB_closeWindow{
	height:25px;
	padding:11px 25px 10px 0;
	float:right;
}

#TB_closeAjaxWindow{
	padding:7px 10px 5px 0;
	margin-bottom:1px;
	text-align:right;
	float:right;
}

#TB_ajaxWindowTitle{
	float:left;
	padding:7px 0 5px 10px;
	margin-bottom:1px;
	font-size: 22px;
}

#TB_title{
	background-color: #660000;
	color: #F2F5ED;
	height:40px;
}
#TB_title a {
	color: white !important;
	border-bottom: 1px dotted #F2F5ED;
}

#TB_ajaxContent{
	clear:both;
	padding:2px 15px 15px 15px;
	overflow:auto;
	text-align:left;
	line-height:1.4em;
}

#TB_ajaxContent.TB_modal{
	padding:15px;
}

#TB_ajaxContent p{
	padding:5px 0px 5px 0px;
}

#TB_load{
	position: fixed;
	display:none;
	height:13px;
	width:208px;
	z-index:103;
	top: 50%;
	left: 50%;
	margin: -6px 0 0 -104px; /* -height/2 0 0 -width/2 */
}

* html #TB_load { /* ie6 hack */
position: absolute;
margin-top: expression(0 - parseInt(this.offsetHeight / 2) + (TBWindowMargin = document.documentElement && document.documentElement.scrollTop || document.body.scrollTop) + 'px');
}

#TB_HideSelect{
	z-index:99;
	position:fixed;
	top: 0;
	left: 0;
	background-color:#fff;
	border:none;
	filter:alpha(opacity=0);
	-moz-opacity: 0;
	opacity: 0;
	height:100%;
	width:100%;
}

* html #TB_HideSelect { /* ie6 hack */
     position: absolute;
     height: expression(document.body.scrollHeight > document.body.offsetHeight ? document.body.scrollHeight : document.body.offsetHeight + 'px');
}

#TB_iframeContent{
	clear:both;
	border:none;
	margin-bottom:-1px;
	margin-top:1px;
	_margin-bottom:1px;
}

/* @end */

/* @group Debugging Section */

#debugging-toggle {
	text-align: center;
}
#debugging-toggle img {
	cursor: pointer;
}

#rdoc-debugging-section-dump {
	display: none;
	margin: 0 2em 2em;
	background: #FFC200;
	border: 1px solid #999;
}



/* @end */
